================================================
 `xotl.tools.testing`:mod: -- Utilities testing
================================================

.. module:: xotl.tools.testing

Provides `sample data generators`__ for xotl.tools's data structures.

.. warning:: You must install ``xotl.tools[testing]`` in order to get extra
             dependencies.

.. versionadded:: 1.8.2


__ hypothesis_
.. _hypothesis: https://hypothesis.readthedocs.io/


.. toctree::
   :glob:

   testing/*
